Learn R Programming

palinsol (version 0.93)

Insol: Computes incoming solar radiation (insolation)

Description

Computes incoming solar radiation (insolation) for a given astronomical configuration, true solar longitude and latitude

Usage

Insol (orbit,long=pi/2, lat=65*pi/180,S0=1365)

Value

Daily-mean insolation (assuming fixed astronomical parameters during a true solar day)

Arguments

orbit

Output from a solution, such as ber78, ber90 or la04

long

true solar longitude

lat

latitude

S0

Total solar irradiance

Author

Michel Crucifix, U. catholique de Louvain, Belgium.

Details

True solar longitude is measured in radians:

pi/2for June solstice
pifor September equinox
3 * pi/2for December solstice
0for Spring equinox

It may be obtained for a given day in the year using the function day2l.

References

Berger, A. L. (1978). Long-term variations of daily insolation and Quaternary climatic changes, J. Atmos. Sci., 35, 2362-2367.

Examples

Run this code

## make a little wrapper, with all default values

insolation <- function(times, astrosol=ber78,...)
  sapply(times, function(tt) Insol(orbit=astrosol(tt)))

tts <- seq(from = -400e3, to = 0, by = 1e3)
isl <- insolation(tts, ber78)
plot(tts, isl, typ='l')

Run the code above in your browser using DataLab