Learn R Programming

palinsol (version 0.92)

thrins: Integrated insolation for all days exceeding a threshold

Description

Integrated insolation over the part during which daily-mean insolation exceeds a threshold, expressed in W/m2

Usage

thrins  (lat=65*pi/180,orbit,threshold=400,...)

Arguments

lat
latitude
orbit
Output from a solution, such as ber78, ber90 or la04
threshold
threshold insolation ,in W/m2
...
other arguments to be passed to Insol

Value

  • Time-integrated insolation in kJ/m2 . The quantity is calculated by brute-force integration with a 1-degree time-step in true solar longitude and this can be quite slow if long series are to be calculated.

Details

Algorithm is by M. Crucifix, but the idea of thresholded insolation is due to Huybers and Tziperman (2008), reference below.

References

P. Huybers and E. Tziperman (2008), Integrated summer insolation forcing and 40,000-year glacial cycles: The perspective from an ice-sheet/energy-balance model, Paleoceanography, 23.